@@ -43,10 +43,11 @@ class KeyCode(object):
     #: The names of attributes used as platform extensions.
     _PLATFORM_EXTENSIONS = []
 
-    def __init__(self, vk=None, char=None, is_dead=False, **kwargs):
+    def __init__(self, vk=None, char=None, is_dead=False, escaped=False, **kwargs):
         self.vk = vk
         self.char = six.text_type(char) if char is not None else None
         self.is_dead = is_dead
+        self.escaped = escaped
 
         if self.is_dead:
             try:
