@@ -42,7 +42,8 @@ from pynput_robocorp._util.win32 import (
     ListenerMixin,
     SendInput,
     SystemHook,
-    VkKeyScan)
+    VkKeyScan,
+    MapVirtualKey)
 from . import _base
 
 
@@ -72,21 +73,21 @@ class KeyCode(_base.KeyCode):
             vk = self.vk
             scan = self._scan or 0
             flags = 0
+        elif self.escaped:
+            vk = VkKeyScan(self.char) & 0xff
+            scan = MapVirtualKey(vk, 0)
+            flags = 0
         else:
-            res = VkKeyScan(self.char)
-            if (res >> 8) & 0xFF == 0:
-                vk = res & 0xFF
-                scan = self._scan or 0
-                flags = 0
-            else:
-                vk = 0
-                scan = ord(self.char)
-                flags = KEYBDINPUT.UNICODE
+            vk = 0
+            scan = ord(self.char)
+            flags = KEYBDINPUT.UNICODE
+
         state_flags = (KEYBDINPUT.KEYUP if not is_press else 0)
-        return dict(
-            dwFlags=(self._flags or 0) | flags | state_flags,
-            wVk=vk,
-            wScan=scan)
+        return {
+            "dwFlags": (self._flags or 0) | flags | state_flags,
+            "wVk": vk,
+            "wScan": scan
+        }
 
     @classmethod
     def _from_ext(cls, vk, **kwargs):
@@ -180,14 +181,13 @@ class Controller(_base.Controller):
         super(Controller, self).__init__(*args, **kwargs)
 
     def _handle(self, key, is_press):
-        SendInput(
-            1,
-            ctypes.byref(INPUT(
-                type=INPUT.KEYBOARD,
-                value=INPUT_union(
-                    ki=KEYBDINPUT(**key._parameters(is_press))))),
-            ctypes.sizeof(INPUT))
+        ki = KEYBDINPUT(**key._parameters(is_press))
+        inp = INPUT(type=INPUT.KEYBOARD, value=INPUT_union(ki=ki))
 
+        cInputs = 1
+        pInputs = ctypes.byref(inp)
+        cbSize = ctypes.sizeof(INPUT)
+        SendInput(cInputs, pInputs, cbSize)
 
 class Listener(ListenerMixin, _base.Listener):
     #: The Windows hook ID for low level keyboard events, ``WH_KEYBOARD_LL``
